@@ -74,6 +74,7 @@
    /* Put the tokens into the symbol table, so that GDB and other debuggers
       know about them.  */
    enum yytokentype {
+     END = 0,
      STRING = 258,
      NUM = 259,
      KEYWORD = 260,
@@ -84,6 +85,7 @@
    };
 #endif
 /* Tokens.  */
+#define END 0
 #define STRING 258
 #define NUM 259
 #define KEYWORD 260
@@ -498,8 +500,8 @@ static const yytype_int8 yyrhs[] =
 /* YYRLINE[YYN] -- source line where rule number YYN was defined.  */
 static const yytype_uint8 yyrline[] =
 {
-       0,   119,   119,   120,   123,   124,   126,   128,   130,   132,
-     136,   139,   142
+       0,   120,   120,   121,   124,   125,   127,   129,   131,   133,
+     137,   140,   143
 };
 #endif
 
@@ -508,9 +510,9 @@ static const yytype_uint8 yyrline[] =
    First, the terminals, then, starting at YYNTOKENS, nonterminals.  */
 static const char *const yytname[] =
 {
-  "$end", "error", "$undefined", "STRING", "NUM", "KEYWORD", "LISTOPEN",
-  "LISTCLOSE", "EOFF", "ERROR", "$accept", "input", "list", "keyvalue",
-  "key", "num", "string", 0
+  "\"end of file\"", "error", "$undefined", "STRING", "NUM", "KEYWORD",
+  "LISTOPEN", "LISTCLOSE", "EOFF", "ERROR", "$accept", "input", "list",
+  "keyvalue", "key", "num", "string", 0
 };
 #endif
 
